# initialize compatibility version rather main version
MODULES_USE_COMPAT_VERSION=1
export MODULES_USE_COMPAT_VERSION

shell=$(/usr/bin/basename $(/usr/bin/ps -p $$ -ocomm=))

if [ -f /usr/share/Modules/init/$shell ]; then
   source /usr/share/Modules/init/$shell
else
   source /usr/share/Modules/init/sh
fi
